<?php
require_once("APIView.php");

class locations extends APIView {
    public $dbg = true;
    public $auth = "location";
    public $checkEndpoint = false;
    public $checkAction = false;

    public $routeMap = array(
        'getServices' => array(
            'fn' => 'getServices'
        ),
        'addLocation' => array(
            'fn' => 'addLocation',
            'auth' => 'admin',
            'req' => array(
                'locName',
                'num_licenses',
                'has_OnlineOrdering',
                'has_ScheduleGofer',
                'has_ReportAPI',
                'has_ReportGofer',
                'has_Loyalty',
                'emailAddresses'
            )
        ),
        'getLocation' => array(
            'fn' => 'getLocation',
            'auth' => 'admin'
        ),
        'updateServicesLocation' => array(
            'fn' => 'updateServicesLocation',
            'auth' => 'admin'
        )
    );

    public function getServices() {
        $locationID = $_SESSION['locationID'];
        $location = (new Location())->read($locationID);

        $result_data = array(
            "has_OnlineOrdering" => $location->has_OnlineOrdering,
            "has_ScheduleGofer" => $location->has_ScheduleGofer,
            "has_ReportAPI" => $location->has_ReportAPI,
            "has_ReportGofer" => $location->has_ReportGofer,
            "has_Loyalty" =>$location->has_Loyalty
        );

        if (BridgeScheduleGofer::endpointEnabled($locationID,"schedule"))
        {
            $sgSettings = (new ScheduleGoferSettings())->read($locationID);
            $sgLocID = $sgSettings->loc_id;
            $result_data["sg_locID"] = $sgLocID;
        }

        return $result_data;
    }

    public function addLocation(){

        $data = array(
            'api_id' => Utils::calculateRandomToken(8),
            'api_key' => Utils::calculateRandomToken(16)
        );

        $data = array(
            'has_OnlineOrdering' => $this->DATA['has_OnlineOrdering'],
            'has_ScheduleGofer' => $this->DATA['has_ScheduleGofer'],
            'has_ReportAPI' => $this->DATA['has_ReportAPI'],
            'has_ReportGofer' => $this->DATA['has_ReportGofer'],
            'has_Loyalty' => $this->DATA['has_Loyalty'],
            'location_name' => $this->DATA['locName'],
            'api_id' => $data['api_id'],
            'api_key' => $data['api_key']
        );

        $location = (new Location())->create($data);

        $locID = $location->location_id;

        if ($this->DATA['num_licenses'] != 0) {
            for ($i = 0; $i < $this->DATA['num_licenses']; $i++)
            {
                $serial = OCActivation::generateSerial();

                $insertArray = array(
                    "location_id" => $locID,
                    "serial" => $serial,
                    "active" => "N"
                );

                $active = (new Activation())->create($insertArray);

                $serials[] = $serial;
            }
        }

        OCLocation::sendLicenseEmail($this->DATA['emailAddresses'], $serials, $this->DATA['locName'], $data['api_id'], $data['api_key'], $locID);

        return $location;

    }

    public function getLocation(){
        $locID = $this->DATA['locID'];

        $location = (new Location())->read($locID);

        return $location;

    }

    public function updateServicesLocation(){

        $data = array(
            'has_OnlineOrdering' => $this->DATA['has_OnlineOrdering'],
            'has_ScheduleGofer' => $this->DATA['has_ScheduleGofer'],
            'has_ReportAPI' => $this->DATA['has_ReportAPI'],
            'has_ReportGofer' => $this->DATA['has_ReportGofer'],
            'has_Loyalty' => $this->DATA['has_Loyalty']
        );

        $location = (new Location())->read($this->DATA['location_id'])->update($data);

        return $location;
    }
}

new locations();