<?php
require_once("APIView.php");

class loyalty extends APIView {
    public $dbg = true;
    public $auth = "location";
    public $checkEndpoint = false;
    public $checkAction = false;

    public $routeMap = array(
        'addCustomer' => array(
            'fn' => 'addCustomer',
            'req' => array(
                'fname',
                'lname',
                'email',
                'phone',
                'address1',
                'city',
                'state',
                'zipcode'
            )
        ),
        'updateCustomer' => array(
            'fn' => 'updateCustomer',
            'req' => array(
                'customer_id',
                'fname',
                'lname',
                'email',
                'phone',
                'address1',
                'city',
                'state',
                'zipcode'
            )
        ),
        'getCustomer' => array(
            'fn' => 'getCustomer',
            'req' => array(
                'customer_id'
            )
        ),
        'getCustomerCards' => array(
            'fn' => 'getCustomerCards',
            'req' => array(
                'customer_id'
            )
        ),
        'checkCard' => array(
            'fn' => 'checkCard',
            'req' => array(
                'card_num'
            )
        ),
        'addCardToCustomer' => array(
            'fn' => 'addCardToCustomer',
            'req' => array(
                'card_num',
                'customer_id'
            )
        ),
        'getUpdatedCustomers' => array(
            'fn' => 'getUpdatedCustomers',
            'req' => array(
                'last_date'
            )
        ),
        'addMember' => array(
            'fn' => 'addMember',
            'req' => array(
                'status',
                'start_date',
                'type',
                'barcode',
                'barcode_other',
                'dog_walker',
                'vet_name',
                'vet_phone',
                'notes'
            )
        ),
        'updateMember' => array(
            'fn' => 'updateMember',
            'req' => array(
                'member_id',
                'status',
                'start_date',
                'type',
                'barcode',
                'barcode_other',
                'dog_walker',
                'vet_name',
                'vet_phone',
                'notes'
            )
        ),
        'getMember' => array(
            'fn' => 'getMember',
            'req' => array(
                'member_id'
            )
        ),
        'getUpdatedMembers' => array(
            'fn' => 'getUpdatedMembers',
            'req' => array(
                'last_date'
            )
        ),
        'addDog' => array(
            'fn' => 'addDog',
            'req' => array(
                'name',
                'size',
                'color',
                'breed',
                'age',
                'birth_month'
            )
        ),
        'updateDog' => array(
            'fn' => 'updateDog',
            'req' => array(
                'dog_id',
                'name',
                'size',
                'color',
                'breed',
                'age',
                'birth_month'
            )
        ),
        'getDog' => array(
            'fn' => 'getDog',
            'req' => array(
                'dog_id'
            )
        ),
        'getUpdatedDogs' => array(
            'fn' => 'getUpdatedDogs',
            'req' => array(
                'last_date'
            )
        ),
        'getDogsByMemberID' => array(
            'fn' => 'getDogsByMemberID',
            'req' => array(
                'member_id'
            )
        ),
        'getCustomersByMemberID' => array(
            'fn' => 'getCustomersByMemberID',
            'req' => array(
                'member_id'
            )
        ),
        'getMemberByBarcode' => array(
            'fn' => 'getMemberByBarcode',
            'req' => array(
                'barcode'
            )
        )
    );

    public function addCustomer() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */
        $customerID = BridgeLoyalty::addCustomer($this->DATA['fname'], $this->DATA['lname'],$this->DATA['email'], $this->DATA['phone'], $this->DATA['address1'], $this->DATA['address2'], $this->DATA['city'], $this->DATA['state'], $this->DATA['zipcode'], $this->DATA['birthdate']);

        return $customerID;
    }

    public function updateCustomer() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */

        $result = BridgeLoyalty::updateCustomer($this->DATA['customer_id'], $this->DATA['fname'], $this->DATA['lname'],$this->DATA['email'], $this->DATA['phone'], $this->DATA['address1'], $this->DATA['address2'], $this->DATA['city'], $this->DATA['state'], $this->DATA['zipcode'], $this->DATA['birthdate']);

        return $result;
    }

    public function getCustomer() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */

        $result = BridgeLoyalty::getCustomer($this->DATA['customer_id']);

        return $result;
    }

    public function getCustomerCards() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */

        $result = BridgeLoyalty::getCustomerCards($this->DATA['customer_id']);

        return $result;
    }

    public function checkCard() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        $result = BridgeLoyalty::checkCard($this->DATA['card_num']);

        return $result;
    }

    public function addCardToCustomer() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        $result = BridgeLoyalty::addCardToCustomer($this->DATA['card_num'], $this->DATA['customer_id']);

        return $result;
    }

    public function getUpdatedCustomers() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */

        $result = BridgeLoyalty::getUpdatedCustomers($this->DATA['last_date']);

        return $result;
    }

    public function addMember() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */
        $memberID = BridgeLoyalty::addDogParkMember($this->DATA['status'], $this->DATA['start_date'],$this->DATA['type'], $this->DATA['barcode'], $this->DATA['barcode_other'], $this->DATA['dog_walker'], $this->DATA['vet_name'], $this->DATA['vet_phone'], $this->DATA['notes']);

        return $memberID;
    }

    public function updateMember() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */

        $result = BridgeLoyalty::updateDogParkMember($this->DATA['member_id'], $this->DATA['status'], $this->DATA['start_date'],$this->DATA['type'], $this->DATA['barcode'], $this->DATA['barcode_other'], $this->DATA['dog_walker'], $this->DATA['vet_name'], $this->DATA['vet_phone'], $this->DATA['notes']);

        return $result;
    }

    public function getMember() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */

        $result = BridgeLoyalty::getMember($this->DATA['member_id']);

        return $result;
    }

    public function getUpdatedMembers() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */

        $result = BridgeLoyalty::getUpdatedMembers($this->DATA['last_date']);

        return $result;
    }

    public function addDog() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */
        $dogID = BridgeLoyalty::addDog($this->DATA['name'], $this->DATA['size'],$this->DATA['color'], $this->DATA['breed'], $this->DATA['age'], $this->DATA['birth_month']);

        return $dogID;
    }

    public function updateDog() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */

        $result = BridgeLoyalty::updateDog($this->DATA['dog_id'], $this->DATA['name'], $this->DATA['size'],$this->DATA['color'], $this->DATA['breed'], $this->DATA['age'], $this->DATA['birth_month']);

        return $result;
    }

    public function getDog() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */

        $result = BridgeLoyalty::getDog($this->DATA['dog_id']);

        return $result;
    }

    public function getUpdatedDogs() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */

        $result = BridgeLoyalty::getUpdatedDogs($this->DATA['last_date']);

        return $result;
    }

    public function getDogsByMemberID() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */

        $result = BridgeLoyalty::getDogsByMemberID($this->DATA['member_id']);

        return $result;
    }

    public function getCustomersByMemberID() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */

        $result = BridgeLoyalty::getCustomersByMemberID($this->DATA['member_id']);

        return $result;
    }

    public function getMemberByBarcode() {
        $locationID = $_SESSION['locationID'];

        if (!BridgeLoyalty::endpointEnabled($locationID,$this->endpoint))
            throw new APIFailed("The {$this->endpoint} endpoint is not currently enabled for this location.");

        /*
         * @var $ocAuth array
         */

        $result = BridgeLoyalty::getMemberByBarcode($this->DATA['barcode']);

        return $result;
    }
}

new loyalty();