<?php
class BridgeLoyalty {
    public static function endpointEnabled($locationID, $endpoint) {
        switch (trim($endpoint)) {
            case "loyalty":
                $location = (new Location())->read($locationID);
                if ($location->has_Loyalty <> "Y")
                    return false;
                else
                    return true;
                break;
            default:
                return true;
        }
    }

    private static function connect() {
        $locationID = $_SESSION['locationID'];
        $loyaltySettings = (new LoyaltySettings())->read($locationID);

        return  DB::connect(array(
            'host' => $loyaltySettings->server,
            'user' => $loyaltySettings->username,
            'pass' => $loyaltySettings->password,
            'db' => $loyaltySettings->database
        ));
    }

    public static function addCustomer($fname, $lname, $email, $phone, $address1, $address2, $city, $state, $zipcode, $birthdate) {
        $insertArray = array(
            "fname" => $fname,
            "lname" => $lname,
            "email" => $email,
            "phone" => $phone,
            "address1" => $address1,
            "address2" => $address2,
            "city" => $city,
            "state" => $state,
            "zipcode" => $zipcode,
            "birthdate" => $birthdate,
        );

        $customerDB = BridgeLoyalty::connect();

        $customer = (new LoyaltyCustomer(false, $customerDB))->create($insertArray);

        $customerID = $customer->customer_id;

        return $customerID;
    }

    public static function updateCustomer($customerID, $fname, $lname, $email, $phone, $address1, $address2, $city, $state, $zipcode, $birthdate) {
        $customerDB = BridgeLoyalty::connect();

        $updateArray = array(
            "fname" => $fname,
            "lname" => $lname,
            "email" => $email,
            "phone" => $phone,
            "address1" => $address1,
            "address2" => $address2,
            "city" => $city,
            "state" => $state,
            "zipcode" => $zipcode,
            "birthdate" => $birthdate
        );

        $customer = (new LoyaltyCustomer(false, $customerDB))->read($customerID);
        $customer->update($updateArray);

        return true;
    }

    public static function getCustomer($customerID) {
        $customerDB = BridgeLoyalty::connect();

        $customer = (new LoyaltyCustomer(false, $customerDB))->read($customerID);

        return $customer;
    }

    public static function getCustomerCards($customerID) {
        $customerDB = BridgeLoyalty::connect();

        $customers = LoyaltyCards::findAll(array(
            'field' => 'customer_id',
            'val' => $customerID,
            'op' => '='
        ), false, $customerDB);

        return $customers;
    }

    public static function checkCard($cardNum) {
        $customerDB = BridgeLoyalty::connect();

        /**
         * @var LoyaltyCards $cards
         */
        $cards = LoyaltyCards::find(array(
            'field' => 'card_num',
            'val' => $cardNum,
            'limit' => 1
        ), false, $customerDB);

        if (count($cards) == 1)
        {
            if ($cards->customer_id != 0) {
                throw new LoyaltyFailed("Card already registered.");
            }
        }

        return "Card ready for registration.";
    }

    public static function addCardToCustomer($cardNum, $customerID) {
        $customerDB = BridgeLoyalty::connect();

        /**
         * @var LoyaltyCards $cards
         */
        $cards = LoyaltyCards::find(array(
            'field' => 'card_num',
            'val' => $cardNum,
            'limit' => 1
        ), false, $customerDB);

        if (count($cards) == 0)
        {
            $data = array(
                'customer_id' => $customerID,
                'card_num' => $cardNum
            );

            $cards = (new LoyaltyCards())->create($data, false, false, $customerDB);
        } elseif (count($cards) == 1)
        {
            if ($cards->customer_id != 0) {
                throw new LoyaltyFailed("Card already registered.");
            }

            $updateArray = array(
                "customer_id" => $customerID
            );

            $cards->read($cards->vip_card_id);
            $cards->update($updateArray);
        }

        return $cards;
    }

    public static function getUpdatedCustomers($sinceDate) {
        $customerDB = BridgeLoyalty::connect();

        $customers = LoyaltyCustomer::findAll(array(
            'field' => 'last_modified',
            'val' => $sinceDate,
            'op' => '>='
        ), false, $customerDB);
        
        return $customers;
    }

    public static function addDogParkMember($status, $start_date, $type, $barcode, $barcode_other, $dog_walker, $vet_name, $vet_phone, $notes) {
        $insertArray = array(
            "status" => $status,
            "start_date" => $start_date,
            "type" => $type,
            "barcode" => $barcode,
            "barcode_other" => $barcode_other,
            "dog_walker" => $dog_walker,
            "vet_name" => $vet_name,
            "vet_phone" => $vet_phone,
            "notes" => $notes
        );

        $customerDB = BridgeLoyalty::connect();

        $member = (new DogParkMember(false, $customerDB))->create($insertArray);

        $memberID = $member->member_id;

        return $memberID;
    }

    public static function updateDogParkMember($memberID, $status, $start_date, $type, $barcode, $barcode_other, $dog_walker, $vet_name, $vet_phone, $notes) {
        $customerDB = BridgeLoyalty::connect();

        $updateArray = array(
            "status" => $status,
            "start_date" => $start_date,
            "type" => $type,
            "barcode" => $barcode,
            "barcode_other" => $barcode_other,
            "dog_walker" => $dog_walker,
            "vet_name" => $vet_name,
            "vet_phone" => $vet_phone,
            "notes" => $notes
        );

        $member = (new DogParkMember(false, $customerDB))->read($memberID);
        $member->update($updateArray);

        return true;
    }

    public static function getMember($memberID) {
        $customerDB = BridgeLoyalty::connect();

        $member = (new DogParkMember(false, $customerDB))->read($memberID);

        return $member;
    }

    public static function getUpdatedMembers($sinceDate) {
        $customerDB = BridgeLoyalty::connect();

        $members = DogParkMember::findAll(array(
            'field' => 'last_modified',
            'val' => $sinceDate,
            'op' => '>='
        ), false, $customerDB);

        return $members;
    }

    public static function addDog($name, $size, $color, $breed, $age, $birth_month) {
        $insertArray = array(
            "name" => $name,
            "size" => $size,
            "color" => $color,
            "breed" => $breed,
            "age" => $age,
            "birth_month" => $birth_month
        );

        $customerDB = BridgeLoyalty::connect();

        $dog = (new DogParkDog(false, $customerDB))->create($insertArray);

        $dogID = $dog->dog_id;

        return $dogID;
    }

    public static function updateDog($dogID, $name, $size, $color, $breed, $age, $birth_month) {
        $customerDB = BridgeLoyalty::connect();

        $updateArray = array(
            "name" => $name,
            "size" => $size,
            "color" => $color,
            "breed" => $breed,
            "age" => $age,
            "birth_month" => $birth_month
        );

        $dog = (new DogParkDog(false, $customerDB))->read($dogID);
        $dog->update($updateArray);

        return true;
    }

    public static function getDog($dogID) {
        $customerDB = BridgeLoyalty::connect();

        $dog = (new DogParkDog(false, $customerDB))->read($dogID);

        return $dog;
    }

    public static function getUpdatedDogs($sinceDate) {
        $customerDB = BridgeLoyalty::connect();

        $dogs = DogParkDog::findAll(array(
            'field' => 'last_modified',
            'val' => $sinceDate,
            'op' => '>='
        ), false, $customerDB);

        return $dogs;
    }

    public static function getDogsByMemberID($member_id) {
        $customerDB = BridgeLoyalty::connect();

        $dogs = DogParkDog::findAll(array(
            'field' => 'member_id',
            'val' => $member_id,
            'op' => '='
        ), false, $customerDB);

        return $dogs;
    }

    public static function getCustomersByMemberID($member_id) {
        $customerDB = BridgeLoyalty::connect();

        $customers = LoyaltyCustomer::findAll(array(
            'field' => 'member_id',
            'val' => $member_id,
            'op' => '='
        ), false, $customerDB);

        return $customers;
    }

    public static function getMemberByBarcode($barcode) {
        $customerDB = BridgeLoyalty::connect();
        $result = array();
        $members  = DogParkMember::findAll(array(
            'filter' => array(
                'type' => 'OR',
                'args' => array(
                    array(
                        'field' => 'barcode',
                        'val' => $barcode
                    ),
                    array(
                        'field' => 'barcode_other',
                        'val' => $barcode
                    )
                )
            )
        ), false, $customerDB);

        foreach ($members as $k=>$v){
            /**
             * @var DogParkMember $v
             */
            $dogs = BridgeLoyalty::getDogsByMemberID($v->member_id);
            $customers = BridgeLoyalty::getCustomersByMemberID($v->member_id);

            $result['members'] = $v;
            $result['dogs'] = $dogs;
            $result['customers'] = $customers;
        }

        return $result;
    }

}