<?php
class OCActivation {
    private static function prepareSerial($serial) {
        // Strip spaces from Serial Key
        $serial = str_replace(" ", "", $serial);

        // Remove all special characters
        $serial = preg_replace('/[^A-Za-z0-9\-]/', '', $serial);

        // Assign integer values to all letters
        $letters = array(
            "A" => "1",
            "B" => "2",
            "C" => "3",
            "D" => "4",
            "E" => "5",
            "F" => "6",
            "G" => "7",
            "H" => "8",
            "I" => "9",
            "J" => "10",
            "K" => "11",
            "L" => "12",
            "M" => "13",
            "N" => "14",
            "O" => "15",
            "P" => "16",
            "Q" => "17",
            "R" => "18",
            "S" => "19",
            "T" => "20",
            "U" => "21",
            "V" => "22",
            "W" => "23",
            "X" => "24",
            "Y" => "25",
            "Z" => "26",
        );

        $serial = str_ireplace(array_keys($letters), array_values($letters), $serial);

        // collect only middle 8 digits
        if (strlen($serial) > 8) {
            $serial = substr($serial, floor((strlen($serial) / 2)) - 4,8);
        }

        return $serial;
    }

    private static function returnCode($serial) {
        $serial = OCActivation::prepareSerial($serial);

        $code = 1/30000 * ($serial * $serial + 64 / $serial + ($serial / 4));

        if ($code < 100)
            $code = $code * 100;

        if ($code < 1000)
            $code = $code * 1000;

        return (int)$code;
    }

    public static function activateSerial($serial) {
        /**
         * @var Activation $activation
         */
        $findArray = array(
            'field' => 'serial',
            'val' => $serial,
            'limit' => 1
        );

        $activation = Activation::find($findArray);

        if (count($activation) == 0)
            throw new ActivationFailed("Serial number can not be located.");

        if ($activation->active == "Y")
            throw new ActivationFailed("Serial number already active.");

        // All good, so create activation code and return
        $code = OCActivation::returnCode($serial);

        $updateArray = array(
            "activation_code" => $code,
            "date_activated" => date("Y-m-d H:i:s"),
            "active" => "Y"
        );

        $activation->read($activation->serial_id);
        $activation->update($updateArray);

        return $code;
    }

    public static function phoneActivation($code)
    {
        $code = OCActivation::returnCode($code);

        return $code;
    }

    public static function generateSerial()
    {
        $serial = mt_rand(10000000, 99999999);

        return $serial;
    }
}